//========================================================================================
//
//	File:				Part.cpp
//	Release Version:	$ ODF 1 $
//
//	Copyright:	(c) 1993 - 1996 by Apple Computer, Inc., all rights reserved.
//
//========================================================================================

#include "Form.hpp"

#ifndef PART_H
#include "Part.h"
#endif

#ifndef CONTENT_H
#include "Content.h"
#endif

#ifndef BINDING_K
#include "Binding.k"
#endif

#ifndef FRAME_H
#include "Frame.h"
#endif

#ifndef SELECT_H
#include "Select.h"
#endif

// ----- Framework Layer -----

#ifndef FWUTIL_H
#include "FWUtil.h"
#endif

#ifndef FWITERS_H
#include "FWIters.h"
#endif

#ifndef FWPRESEN_H
#include "FWPresen.h"
#endif

// ----- OS Layer -----

#ifndef FWMENU_H
#include "FWMenu.h"
#endif

#ifndef FWCFMRES_H
#include "FWCFMRes.h"
#endif

#ifndef FWRESTYP_H
#include "FWResTyp.h"
#endif

#ifndef FWSUSINK_H
#include "FWSUSink.h"
#endif

#ifndef FWEVENT_H
#include "FWEvent.h"
#endif

#ifndef FWBARRAY_H
#include "FWBArray.h"
#endif

#ifndef FWABOUT_H
#include "FWAbout.h"
#endif

// ----- Foundation Includes -----

#ifndef FWFLOWIN_H
#include "FWFloWin.h"		// FW_CFloatingWindow
#endif

#ifndef FWSTREAM_H
#include "FWStream.h"
#endif

#ifndef FWSTRS_H
#include "FWStrs.h"
#endif

#ifndef FWSUSINK_H
#include "FWSUSink.h"
#endif

// ----- OpenDoc Includes -----

#ifndef SOM_Module_OpenDoc_StdProps_defined
#include <StdProps.xh>
#endif

#ifndef SOM_ODTranslation_xh
#include <Translt.xh>
#endif

#ifndef SOM_ODSession_xh
#include <ODSessn.xh>
#endif

//========================================================================================
// Constants and Globals
//========================================================================================

#define kMainPresentation	"BowersDev:Presentation:Form"

//========================================================================================
//	Runtime info
//========================================================================================

#ifdef FW_BUILD_MAC
#pragma segment Form
#endif

FW_DEFINE_AUTO(CFormPart)

//========================================================================================
//	CFormPart class
//========================================================================================

//----------------------------------------------------------------------------------------
// CFormPart constructor
//----------------------------------------------------------------------------------------

CFormPart::CFormPart(ODPart* odPart) :
	FW_CPart(odPart, FW_gInstance, kPartInfoID),
	fPartContent(NULL),
	fMainPresentation(NULL)
{
}

//----------------------------------------------------------------------------------------
// CFormPart destructor
//----------------------------------------------------------------------------------------

CFormPart::~CFormPart()
{
}

//----------------------------------------------------------------------------------------
// CFormPart::Initialize
//----------------------------------------------------------------------------------------

void CFormPart::Initialize(Environment* ev)
{
	FW_CPart::Initialize(ev);

	// ----- Register Presentations
	fMainPresentation = RegisterPresentation(ev, kMainPresentation, TRUE, 
									 FW_NEW(CFormSelection, (ev, fPartContent)));

	// ----- Initialize my menu -----
	GetMenuBar(ev)->InitializeFromResource(ev, kMenuBar);
}

//----------------------------------------------------------------------------------------
// CFormPart::NewFrame
//----------------------------------------------------------------------------------------

FW_CFrame* CFormPart::NewFrame(Environment* ev,
								ODFrame* odFrame,
								FW_CPresentation* presentation,
								FW_Boolean fromStorage)
{
	FW_UNUSED(fromStorage);
	FW_CFrame* newFrame = NULL;

	if (presentation == fMainPresentation) {
		newFrame = FW_NEW(CFormFrame, (ev, odFrame, presentation, fPartContent));
	}
	return newFrame;
}

//------------------------------------------------------------------------------
// CFormPart::NewPartContent
//------------------------------------------------------------------------------

FW_CContent* CFormPart::NewPartContent(Environment* ev)
{
	fPartContent = FW_NEW(CFormContent, (ev, this));
	return fPartContent;
}

//----------------------------------------------------------------------------------------
// CFormPart::DoMenu
//----------------------------------------------------------------------------------------

FW_Boolean CFormPart::DoMenu(Environment* ev, const FW_CMenuEvent& theMenuEvent)
{
	FW_Boolean menuHandled = TRUE;
	ODCommandID id = theMenuEvent.GetCommandID(ev);

	switch (id)
	{
		case cStuffCommand:
		case cMoreStuffCommand:
		case cStillMoreCommand:
			this->DoFormCommand(ev, id);
			menuHandled = TRUE;
			break;

		case kODCommandAbout:
			::FW_About(ev, this, kAbout);
			break;

		default:
			menuHandled = FALSE;
	}

	return menuHandled;
}

//----------------------------------------------------------------------------------------
// CFormPart::DoAdjustMenus
//----------------------------------------------------------------------------------------

FW_Boolean CFormPart::DoAdjustMenus(Environment* ev, FW_CMenuBar* menuBar, 
									 FW_Boolean hasMenuFocus,
									 FW_Boolean isRoot)
{
	if (hasMenuFocus)
	{
		menuBar->EnableCommand(ev, cStuffCommand, TRUE);
		menuBar->EnableCommand(ev, cMoreStuffCommand, TRUE);
		menuBar->EnableCommand(ev, cStillMoreCommand, TRUE);
	}

	return FALSE;
}

//----------------------------------------------------------------------------------------
// CFormPart::DoFormCommand
//----------------------------------------------------------------------------------------

void CFormPart::DoFormCommand(Environment* ev, ODCommandID id)
{
}

//----------------------------------------------------------------------------------------
// CFormPart::PartChanged
//----------------------------------------------------------------------------------------

void CFormPart::PartChanged(Environment* ev)
{
	// Mark the document's draft as changed so it can be saved
	this->Changed(ev);

	// Mark the display frame as changed, so that containing parts can update links
	fMainPresentation->ContentUpdated(ev);

	// Force all display frames to be redrawn
	fMainPresentation->Invalidate(ev);
}
